@@ -296,15 +296,15 @@ class DataApi:
             df_money = df_all_pivot['amount'].fillna(0)
             df_up_limit = df_all_pivot['up_limit'].fillna(method='ffill')
             df_down_limit = df_all_pivot['down_limit'].fillna(method='ffill')
-            df_open = DataApi.__adj_fields(df_open, arr_adj)
-            df_close = DataApi.__adj_fields(df_close, arr_adj)
+            df_open = self.__adj_fields(df_open, arr_adj)
+            df_close = self.__adj_fields(df_close, arr_adj)
             df_pre_close = df_close.shift(1)
-            df_high = DataApi.__adj_fields(df_high, arr_adj)
-            df_low = DataApi.__adj_fields(df_low, arr_adj)
-            df_high_limit = DataApi.__adj_fields(df_up_limit,
-                                                 arr_adj)
-            df_low_limit = DataApi.__adj_fields(df_down_limit,
-                                                arr_adj)
+            df_high = self.__adj_fields(df_high, arr_adj)
+            df_low = self.__adj_fields(df_low, arr_adj)
+            df_high_limit = self.__adj_fields(df_up_limit,
+                                              arr_adj)
+            df_low_limit = self.__adj_fields(df_down_limit,
+                                             arr_adj)
             df_money = pd.DataFrame(df_money.values,
                                     columns=df_volume.columns, index=df_volume.index)
             ret = {"open": df_open, "high": df_high, 'low': df_low, 'close': df_close, 'volume': df_volume,
@@ -430,6 +430,10 @@ class DataApi:
                             else:
                                 data[col] = data[col] * data['adj_factor'] / float(fcts['adj_factor'][0])
                             data[col] = data[col].map(number_format)
+                        if adj == 'hfq':
+                            data['vol'] = data['vol'] / data['adj_factor']
+                        else:
+                            data['vol'] = data['vol'] / data['adj_factor'] * float(fcts['adj_factor'][0])
                         for col in PRICE_COLS:
                             data[col] = data[col].astype(float)
                         data = data.drop('adj_factor', axis=1)
@@ -470,6 +474,7 @@ class DataApi:
                             data['ma_v_%s' % a] = mas(data['vol'], a).map(number_format).shift(-(a - 1))
                             data['ma_v_%s' % a] = data['ma_v_%s' % a].astype(float)
                 data['trade_date'] = pd.to_datetime(data['trade_date'])
+                data = data.set_index('trade_date', drop=True)
                 return data
             except Exception as e:
                 print(e)
